@@ -11,12 +11,12 @@ test_that("piecewise_equalization",
 	range_bad2 <- c(-1,1)
 	range_bad3 <- c(NA, 255)
 	range_badorder <- c(255, 0)
-	expect_equal(EqualizePiecewise(notim, N), NULL)
-	expect_equal(EqualizePiecewise(gim2, N), NULL)
-    expect_equal(EqualizePiecewise(im, N), NULL)
-    expect_equal(EqualizePiecewise(gim, N, range = range_bad1), NULL)
-	expect_equal(EqualizePiecewise(gim, N, range = range_bad2), NULL)
-	expect_equal(EqualizePiecewise(gim, N, range = range_bad3), NULL)
+	expect_error(EqualizePiecewise(notim, N))
+	expect_error(EqualizePiecewise(gim2, N))
+    expect_error(EqualizePiecewise(im, N))
+    expect_error(EqualizePiecewise(gim, N, range = range_bad1))
+	expect_error(EqualizePiecewise(gim, N, range = range_bad2))
+	expect_error(EqualizePiecewise(gim, N, range = range_bad3))
     expect_warning(EqualizePiecewise(gim, N, range = range_badorder))
     expect_equal(EqualizePiecewise(gim, N), EqualizePiecewise(gim, N, range = range_badorder))
 })
\ No newline at end of file
